.. _spkg_cachetools:

cachetools: Extensible memoizing collections and decorators
===========================================================

Description
-----------

Extensible memoizing collections and decorators

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/cachetools/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    5.3.3

version_requirements.txt::

    cachetools

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install cachetools

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i cachetools

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-python-cachetools


If the system package is installed, ``./configure`` will check if it can be used.
